Image2console
=============

Image2console is a WIP python module that will allow you to print an
image in your console.

-  Great for choose your own adventure games or other text based games
-  Display logo's in the console
-  Anything else you could need

Installation
~~~~~~~~~~~~

    pip install image2console

Use
~~~

    - from image2console import string\_text
    - print(string\_text("YOUR\_IMAGE.jpg",size\*))

Size ranges from 1-100

Todos
~~~~~

-  Add support for other image types
-  General improvments
-  Add more capabilitys and functions

License
~~~~~~~

-  Mit

